@@ -575,7 +575,7 @@ findPropulsiveEnd <- function(accel, concentric) {
 	if(length(which(accel[concentric]<=-g)) > 0) 
 		propulsiveEnd = min(which(accel[concentric] <= -g))
 	else
-		propulsiveEnd = max(concentric)
+		propulsiveEnd = length(concentric)
 	
 return (propulsiveEnd)
 }
@@ -619,7 +619,7 @@ print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
 	concentric = 0
 	propulsiveEnd = 0
 
-print(c("at kinematicsF eccon==", eccon))
+	print(c("at kinematicsF eccon: ", eccon, " length(displacement): ",length(displacement)))
 
 	#search propulsiveEnd
 	if(isPropulsive) {
@@ -632,6 +632,7 @@ print(c("at kinematicsF eccon==", eccon))
 			isometric = phases$isometric
 			concentric = phases$concentric
 			propulsiveEnd = length(eccentric) + length(isometric) + findPropulsiveEnd(accel$y,concentric)
+			print(c("lengths: ", length(eccentric), length(isometric), findPropulsiveEnd(accel$y,concentric), propulsiveEnd))
 		} else if(eccon=="e") {
 			#not eccon="e" because not propulsive calculations on eccentric
 		} else { #ecS
@@ -681,7 +682,6 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra) {
 	meanForce <- mean(kinematics$force)
 	maxForce <- max(abs(kinematics$force))
 
-
 	#here paf is generated
 	#mass is not used by pafGenerate, but used by Kg/W (loadVSPower)
 	#meanForce and maxForce are not used by pafGenerate, but used by F/S (forceVSSpeed)
@@ -915,11 +915,11 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		#TODO: con-ecc is opposite
 		if(isometricUse) {
 			eccentric=1:min(speed.ext$cross[crossMinRow,1])
-			isometric=c(min(speed.ext$cross[crossMinRow,1]+1), max(speed.ext$cross[crossMinRow,2]))
+			isometric=min(speed.ext$cross[crossMinRow,1]+1):max(speed.ext$cross[crossMinRow,2])
 			concentric=max(speed.ext$cross[crossMinRow,2]+1):length(displacement)
 		} else {
 			eccentric=1:mean(speed.ext$cross[crossMinRow,1])
-			#isometric=c(mean(speed.ext$cross[crossMinRow,1]+1), mean(speed.ext$cross[crossMinRow,2]))
+			#isometric=mean(speed.ext$cross[crossMinRow,1]+1);mean(speed.ext$cross[crossMinRow,2])
 			concentric=mean(speed.ext$cross[crossMinRow,2]+1):length(displacement)
 		}
 
@@ -952,13 +952,18 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	#accel2 <- accel2 * 1000
 	#print(accel2)
 
-	#propulsive phase ends when accel is -9.8
-	if(length(which(accel$y[concentric]<=-g)) > 0 & isPropulsive) {
-		propulsiveEnd = min(which(accel$y[concentric]<=-g))
-	} else {
-		propulsiveEnd = max(concentric)
+	#define a propulsiveEnd value because it's used also in non-propulsive curves
+	propulsiveEnd = length(displacement)
+
+	if(isPropulsive) {
+		propulsiveEnd = findPropulsiveEnd(accel$y, concentric)
+		if(eccon != "c")
+			propulsiveEnd = length(eccentric) + length(isometric) + propulsiveEnd
 	}
 
+
+	print(c("propulsiveEnd at paint", propulsiveEnd))
+
 	meanSpeedC = mean(speed$y[min(concentric):max(concentric)])
 	if(isPropulsive) {
 		meanSpeedC = mean(speed$y[min(concentric):propulsiveEnd])
@@ -2668,6 +2673,16 @@ doProcess <- function(options) {
 				quit()
 			}
 			npj <- neuromuscularProfileGetData(displacement, curves, (MassBody + MassExtra), SmoothingOneC)
+
+			if(npj == -1) {
+				plot(0,0,type="n",axes=F,xlab="",ylab="")
+				text(x=0,y=0,paste(translate("Not enough data."), "\n",
+						   translate("Need at least three jumps executed on the odd concentric phases"),
+						   " (1 con, 3 con, 5 con, ...)."), cex=1.5)
+				dev.off()
+				write("", OutputData1)
+				quit()
+			}
 					    
 			np.bar.load <- mean(c(
 					      npj[[1]]$e1$rfd.avg,
