@@ -207,7 +207,7 @@ public class Constants
 		"SQRT(2*9,81* " + Catalog.GetString("height") + "(m))";
 */
 	public static string PotencyLewisFormulaShort = Catalog.GetString("Peak power") + " (Lewis, 1974) " +
-		"\n" + Catalog.GetString("adapted (added g to have Watts)");
+		Catalog.GetString("(Watts)");
 	public static string PotencyLewisFormula = PotencyLewisFormulaShort + "\n" +
 		"(SQRT(4,9)*9,8*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ") * SQRT(" + Catalog.GetString("height") + "(m)))";
 	//see: http://www.dtic.mil/cgi-bin/GetTRDoc?AD=ADA218194&Location=U2&doc=GetTRDoc.pdf
@@ -370,8 +370,11 @@ public class Constants
 	public static string FileNameOpen = "gtk-open.png";
 	public static string FileNameOpen1 = "gtk-open-1.png";
 	public static string FileNameOpenPlus = "gtk-open-plus.png";
+
 	public static string FileNameCSVHeadersIcon = "import-csv-headers.png";
 	public static string FileNameCSVNoHeadersIcon = "import-csv-noheaders.png";
+	public static string FileNameCSVName1Icon = "import-csv-name-1-column.png";
+	public static string FileNameCSVName2Icon = "import-csv-name-2-columns.png";
 
 	public static string FileNameJumps = "stock_up.png";
 	public static string FileNameJumpsRJ = "stock_up_down.png";
@@ -410,6 +413,9 @@ public class Constants
 	public static string FileNameEncoderAnalyzeRangeIcon = "encoder-analyze-range.png";
 	public static string FileNameEncoderAnalyzeTimeToPPIcon = "encoder-analyze-time-to-pp.png";
 	
+	public static string FileNameAutoPersonSkipIcon = "auto-person-skip.png";
+	public static string FileNameAutoPersonRemoveIcon = "auto-person-remove.png";
+	
 	//30 colors defined
 	//see als UtilGtk that's not used by the server
 	public static string [] Colors = {
@@ -769,6 +775,7 @@ public class Constants
 		"Mean speed in concentric propulsive phase",
 		"Sorry, no curves matched your criteria.",
 		"Need 6 jumps and 4 phases for each jump",
+		"Need at least three jumps executed on the odd concentric phases",
 		"Starting R",
 		"Loading libraries",
 		"Starting process",
@@ -814,6 +821,7 @@ public class Constants
 		Catalog.GetString("Mean speed in concentric propulsive phase"),
 		Catalog.GetString("Sorry, no curves matched your criteria."),
 		Catalog.GetString("Need 6 jumps and 4 phases for each jump"),
+		Catalog.GetString("Need at least three jumps executed on the odd concentric phases"),
 		Catalog.GetString("Starting R"),
 		Catalog.GetString("Loading libraries"),
 		Catalog.GetString("Starting process"),
