@@ -591,15 +591,15 @@ public class EventMoreWindow
 	protected string selectedEventName;
 	protected string selectedDescription;
 	public Gtk.Button button_selected;
-	public Gtk.Button button_deleted_current_test; //just to send a signal
+	public Gtk.Button button_deleted_test; //just to send a signal
 	
 	protected bool testOrDelete; //are we going to do a test or to delete a test type (test is true)
-	protected string selectedTestOnMainWindow;
+	protected string [] typesTranslated;
 
 	public EventMoreWindow () {
 	}
 
-	public EventMoreWindow (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow) {
+	public EventMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		/*
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", "chronojump");
@@ -615,7 +615,7 @@ public class EventMoreWindow
 	protected void initializeThings() 
 	{
 		button_selected = new Gtk.Button();
-		button_deleted_current_test = new Gtk.Button();
+		button_deleted_test = new Gtk.Button();
 		
 		createTreeView(treeview_more);
 
@@ -697,9 +697,7 @@ public class EventMoreWindow
 	{
 		deleteTestLine();
 
-		//if deleted test was the selected test, change selected test to default
-		if(selectedTestOnMainWindow == selectedEventName)
-			button_deleted_current_test.Click();
+		button_deleted_test.Click();
 
 		TreeModel model;
 		TreeIter iter;
@@ -721,9 +719,9 @@ public class EventMoreWindow
 		get { return button_selected; }
 	}
 
-	public Button Button_deleted_current_test
+	public Button Button_deleted_test
 	{
-		get { return button_deleted_current_test; }
+		get { return button_deleted_test; }
 	}
 
 	public Button Button_accept {
