@@ -1804,7 +1804,18 @@ public class PersonAddMultipleWindow {
 	[Widget] Gtk.Image image_csv_headers_help;
 	[Widget] Gtk.Image image_csv_noheaders_help;
 	
+	[Widget] Gtk.Table table_headers_1_column;
+	[Widget] Gtk.Table table_no_headers_1_column;
+	[Widget] Gtk.Table table_headers_2_columns;
+	[Widget] Gtk.Table table_no_headers_2_columns;
+	
+	[Widget] Gtk.Image image_name1;
+	[Widget] Gtk.Image image_name2;
+	[Widget] Gtk.Image image_name1_help;
+	[Widget] Gtk.Image image_name2_help;
+	
 	[Widget] Gtk.CheckButton check_headers;
+	[Widget] Gtk.CheckButton check_name_1_column;
 	[Widget] Gtk.Button button_csv_load;
 	[Widget] Gtk.Button button_csv_help;
 	
@@ -1856,6 +1867,8 @@ public class PersonAddMultipleWindow {
 		}
 		
 		PersonAddMultipleWindowBox.putNonStandardIcons ();
+		PersonAddMultipleWindowBox.tablesVisibility ();
+
 		PersonAddMultipleWindowBox.created_table = false;
 
 		PersonAddMultipleWindowBox.person_multiple_infinite.Show ();
@@ -1877,17 +1890,53 @@ public class PersonAddMultipleWindow {
 		
 	void putNonStandardIcons() {
 		Pixbuf pixbuf;
+		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVHeadersIcon);
 		image_csv_headers.Pixbuf = pixbuf;
 		image_csv_headers_help.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVNoHeadersIcon);
 		image_csv_noheaders.Pixbuf = pixbuf;
 		image_csv_noheaders_help.Pixbuf = pixbuf;
+		
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVName1Icon);
+		image_name1.Pixbuf = pixbuf;
+		image_name1_help.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVName2Icon);
+		image_name2.Pixbuf = pixbuf;
+		image_name2_help.Pixbuf = pixbuf;
+	}
+	
+	void tablesVisibility() {
+		table_headers_1_column.Visible = false;
+		table_no_headers_1_column.Visible = false;
+		table_headers_2_columns.Visible = false;
+		table_no_headers_2_columns.Visible = false;
+		
+		if(check_headers.Active) {
+			if(check_name_1_column.Active)
+				table_headers_1_column.Visible = true;
+			else
+				table_headers_2_columns.Visible = true;
+		} else {
+			if(check_name_1_column.Active)
+				table_no_headers_1_column.Visible = true;
+			else
+				table_no_headers_2_columns.Visible = true;
+		}
 	}
 
 	void on_check_headers_toggled (object obj, EventArgs args) {
 		image_csv_headers.Visible = (check_headers.Active == true);
 		image_csv_noheaders.Visible = (check_headers.Active == false);
+
+		tablesVisibility();
+	}
+	
+	void on_check_name_1_column_toggled (object obj, EventArgs args) {
+		image_name1.Visible = (check_name_1_column.Active == true);
+		image_name2.Visible = (check_name_1_column.Active == false);
+		
+		tablesVisibility();
 	}
 	
 	void on_radio_csv_toggled (object obj, EventArgs args) {
@@ -1930,28 +1979,38 @@ public class PersonAddMultipleWindow {
 			List<string> columns = new List<string>();
 			using (var reader = new CsvFileReader(fc.Filename))
 			{
+				bool headersActive = check_headers.Active;
+				bool name1Column = check_name_1_column.Active;
 				int row = 0;
 				while (reader.ReadRow(columns))
 				{
-					string name = "";
+					string fullname = "";
+					string onlyname = "";
 					bool maleOrFemale = true;
 					double weight = 0;
 					int col = 0;
 					foreach(string str in columns) {
 						//if headers are active do not process first row
 						//do not process this first row because weight can be a string
-						if(check_headers.Active && row == 0)
+						if(headersActive && row == 0)
 							continue;
 						
 						Log.Write(":" + str);
-						if(col == 0)
-							name = str;
-						else if(col == 1) {
+
+						if(col == 0) {
+							if(name1Column)
+								fullname = str;
+							else
+								onlyname = str;
+						}
+						else if(col == 1 && ! name1Column)
+							fullname = onlyname + " " + str;
+						else if( (col == 1 && name1Column) || (col == 2 && ! name1Column) ) {
 							//female symbols
 							if(str == "0" || str == "f" || str == "F")
 								maleOrFemale = false;
 						}
-						else if(col == 2) {
+						else if( (col == 2 && name1Column) || (col == 3 && ! name1Column) ) {
 							try {
 								weight = Convert.ToDouble(Util.ChangeDecimalSeparator(str));
 							} catch {
@@ -1971,8 +2030,8 @@ public class PersonAddMultipleWindow {
 						col ++;
 					}
 					//if headers are active do not add first row
-					if( ! (check_headers.Active && row == 0) ) {
-						PersonAddMultipleTable pamt = new PersonAddMultipleTable( name, maleOrFemale, weight);
+					if( ! (headersActive && row == 0) ) {
+						PersonAddMultipleTable pamt = new PersonAddMultipleTable(fullname, maleOrFemale, weight);
 						array.Add(pamt);
 					}
 					
@@ -1997,13 +2056,10 @@ public class PersonAddMultipleWindow {
 	{
 		label_csv_help.Text =
 			"<b>" + Catalog.GetString("Import persons from an spreadsheet. Eg. Excel, LibreOffice, Google Drive.") + "</b>\n\n" +
-			Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n\n" +
-			Catalog.GetString("Spreadsheed need to have this structure:") + "\n" +
-			" - " + Catalog.GetString("First column should be full name of each person.") + "\n" +
-			" - " + Catalog.GetString("Second column should be the gender of the person: Use the values 1/0, or m/f, or M/F to differentiate between male and female.") + "\n" +
-			" - " + Catalog.GetString("Third column should be the weight in Kg.");
-
+			Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n" +
+			Catalog.GetString("Spreadsheed structure need to have this structure:");
 		label_csv_help.UseMarkup = true;
+
 		notebook.CurrentPage = 1;
 	}
 	
